@@ -34,6 +34,8 @@
 #include "bug-buddy.h"
 #include "util.h"
 
+#define d(x)
+
 static gint
 animate (gpointer data)
 {
@@ -69,12 +71,11 @@ start_gdb (void)
 	static CrashType old_type = -1;
 	gchar *app = NULL, *extra = NULL;
 
-	g_message (_("Obtaining stack trace... (%d)"), druid_data.crash_type);
+	d(g_message (_("Obtaining stack trace... (%d)"), druid_data.crash_type));
 
-	if (druid_data.crash_type == CRASH_NONE)
-		return;
-	
 	switch (druid_data.crash_type) {
+	case CRASH_NONE:
+		return;
 	case CRASH_DIALOG:
 		app = gtk_entry_get_text (GTK_ENTRY (GET_WIDGET ("gdb-binary-entry")));
 		extra = gtk_entry_get_text (GTK_ENTRY (GET_WIDGET ("gdb-pid-entry")));
@@ -113,7 +114,7 @@ void
 stop_gdb (void)
 {
 	if (!druid_data.ioc) {
-		g_message (_("gdb has already exited"));
+		d(g_message (_("gdb has already exited")));
 		return;
 	}
 	
@@ -144,7 +145,7 @@ get_trace_from_core (const gchar *core_file)
 	int status;
 	FILE *f;
 
-	gdb_cmd = g_strdup_printf ("gdb --batch --core=%s", core_file);
+	gdb_cmd = g_strdup_printf ("gdb --nw --batch --core=%s", core_file);
 
 	f = popen (gdb_cmd, "r");
 	g_free (gdb_cmd);
@@ -185,7 +186,7 @@ get_trace_from_core (const gchar *core_file)
 	}	
 
 	if (!popt_data.app_file) {
-		g_message ("Setting binary: %s", binary);
+		d(g_message ("Setting binary: %s", binary));
 		popt_data.app_file = g_strdup (binary);
 	}
 
@@ -212,7 +213,7 @@ handle_gdb_input (GIOChannel *ioc, GIOCondition condition, gpointer data)
 	case G_IO_ERROR_AGAIN:
 		goto gdb_try_read;
 	default:
-		g_warning (_("Error on read... aborting"));
+		d(g_warning (_("Error on read... aborting")));
 		stop_gdb ();
 		return FALSE;
 	}
@@ -232,7 +233,8 @@ get_trace_from_pair (const gchar *app, const gchar *extra)
 	GtkWidget *d;
 	int fd;
 	char *app2;
-	char *args[] = { "gdb", 
+	char *args[] = { "gdb",
+			 "--nw",
 			 "--batch", 
 			 "--quiet",
 			 "--command=" BUDDY_DATADIR "/gdb-cmd",
@@ -241,7 +243,7 @@ get_trace_from_pair (const gchar *app, const gchar *extra)
 	args[5] = (char *)extra;
 
 	if (!args[0]) {
-		g_message ("Path: %s", getenv ("PATH"));
+		d(g_message ("Path: %s", getenv ("PATH")));
 		gnome_dialog_run_and_close (
 			GNOME_DIALOG (
 				gnome_error_dialog (_("GDB could not be found on your system.\n"
@@ -266,11 +268,11 @@ get_trace_from_pair (const gchar *app, const gchar *extra)
 
 	args[4] = app2;
 
-	g_message ("About to debug '%s'", app2);
+	d(g_message ("About to debug '%s'", app2));
 	
 	if (!g_file_exists (BUDDY_DATADIR "/gdb-cmd")) {
 		d = gnome_error_dialog (_("Could not find the gdb-cmd file.\n"
-					  "Please try reinstalling bug-buddy."));
+					  "Please try reinstalling Bug Buddy."));
 		gnome_dialog_run_and_close (GNOME_DIALOG (d));
 		g_free (app2);
 		return;
